@@ -7,8 +7,9 @@ from trytond.tools import lstrip_wildcard
 
 class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
-    bank_accounts = fields.Many2Many('bank.account-party.party', 'owner',
-        'account', 'Bank Accounts')
+    bank_accounts = fields.Many2Many(
+        'bank.account-party.party', 'owner', 'account', "Bank Accounts",
+        filter=[('active', '=', True)])
 
     @classmethod
     def search_rec_name(cls, name, clause):
